@@ -4,7 +4,12 @@ export default function report_error({ type, error }) {
   console.error(`[${type}]`, error)
   if (window._config.EXTRAS.indexOf('catalog-integration') !== -1) {
     if (window._config.report_error !== undefined) {
-      window._config.report_error({ type, error })
+      window._config.report_error({
+        appyter: ((nb || {}).metadata || {}).appyter || null,
+        url: window.location.href, 
+        type,
+        error,
+      })
     } else {
       console.warn('[catalog-integration:report_error]: attempting deprecated requirejs resolution')
       get_require(window, 'report_error')
